@@ -19,15 +19,6 @@
 
     cl <- match.call()
     
-    ## get marginal likelihood argument
-    marginal.likelihood  <- match.arg(marginal.likelihood)
-    if (max(B0==0) == 1){
-      if (marginal.likelihood != "none"){
-        warning("Cannot calculate marginal likelihood with improper prior\n")
-        marginal.likelihood <- "none"
-      }
-    }
-    logmarglike <- NULL
     
     ## seeds
     seeds <- form.seeds(seed) 
@@ -47,6 +38,22 @@
     mvn.prior <- form.mvn.prior(b0, B0, K)
     b0 <- mvn.prior[[1]]
     B0 <- mvn.prior[[2]]
+
+
+    ## get marginal likelihood argument
+    marginal.likelihood  <- match.arg(marginal.likelihood)
+    B0.eigenvalues <- eigen(B0)$values
+    if (min(B0.eigenvalues) < 0){
+      stop("B0 is not positive semi-definite.\nPlease respecify and call again.\n")
+    }
+    if (isTRUE(all.equal(min(B0.eigenvalues), 0))){
+      if (marginal.likelihood != "none"){
+        warning("Cannot calculate marginal likelihood with improper prior\n")
+        marginal.likelihood <- "none"
+      }
+    }
+    logmarglike <- NULL
+
     
     ## form the tuning parameter
     tune <- vector.tune(tune, K)
